@@ -46,6 +46,8 @@ def power(base, exponent):
             return float(base) ** float(exponent)
 
 
+def mean(inList):
+    return sum(inList) / len(inList)
 
 
 def sub(minuend, subtrahend):
@@ -82,4 +84,4 @@ def pow(base, exponent):
         if(base - int(base) == 0 and exponent - int(exponent) == 0):
             return int(base) ** int(exponent)
         if(base - int(base) != 0 or exponent - int(exponent) != 0):
-            return float(base) ** float(exponent)
+            return float(base) ** float(exponent)
\ No newline at end of file
